| plsdepot-package | R Documentation |
Different methods for PLS analysis of one or two data tables such as Tucker's Inter-Battery, NIPALS, SIMPLS, SIMPLS-CA, PLS Regression, and PLS Canonical Analysis. The main reference for this software is the awesome book (in French) 'La Regression PLS: Theorie et Pratique' by Michel Tenenhaus.
This package was written by Gaston Sanchez. Maintainer: Frederic Bertrand <frederic.bertrand@lecnam.net>
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.